@@ -58,11 +58,19 @@ class OptsTestCase(utils.TestCase):
             'memcache_security_strategy',
             'memcache_secret_key',
             'memcache_use_advanced_pool',
+            'memcache_tls_enabled',
+            'memcache_tls_cafile',
+            'memcache_tls_certfile',
+            'memcache_tls_keyfile',
+            'memcache_tls_allowed_ciphers',
             'memcache_pool_dead_retry',
             'memcache_pool_maxsize',
             'memcache_pool_unused_timeout',
             'memcache_pool_conn_get_timeout',
             'memcache_pool_socket_timeout',
+            'memcache_sasl_enabled',
+            'memcache_username',
+            'memcache_password',
             'include_service_catalog',
             'enforce_token_bind',
             'auth_type',
@@ -103,11 +111,19 @@ class OptsTestCase(utils.TestCase):
             'memcache_security_strategy',
             'memcache_secret_key',
             'memcache_use_advanced_pool',
+            'memcache_tls_enabled',
+            'memcache_tls_cafile',
+            'memcache_tls_certfile',
+            'memcache_tls_keyfile',
+            'memcache_tls_allowed_ciphers',
             'memcache_pool_dead_retry',
             'memcache_pool_maxsize',
             'memcache_pool_unused_timeout',
             'memcache_pool_conn_get_timeout',
             'memcache_pool_socket_timeout',
+            'memcache_sasl_enabled',
+            'memcache_username',
+            'memcache_password',
             'include_service_catalog',
             'enforce_token_bind',
             'auth_type',
